@@ -30,14 +30,14 @@ use MCE::Loop;
 use SQL::Abstract::Classic;
 use SQL::Inserter;
 use System::Info;
-use Text::Fuzzy;
 use Text::Levenshtein::Damerau::XS;
+use Text::Levenshtein::XS;
 
 use Exporter 'import';
 our @EXPORT = qw(system_identity suite_run calc_scalability);
 our $datadir = dist_dir("Benchmark-DKbench");
 
-our $VERSION = '2.0_005';
+our $VERSION = '2.0_006';
 
 =head1 NAME
 
@@ -49,8 +49,8 @@ Benchmark::DKbench - Perl CPU Benchmark
  # Will print scores for the two runs and multi/single thread scalability
  dkbench
 
- # A dual-thread run with times instead of scores
- dkbench -j 2 -t
+ # A dual-thread "quick" run (with times instead of scores)
+ dkbench -j 2 -q
 
  # If BioPerl is installed, enable the BioPerl benchmarks by downloading Genbank data
  dkbench --setup
@@ -69,16 +69,19 @@ and can be fully customized to run the benchmarks that better suit your own scen
 =head1 INSTALLATION
 
 The only non-CPAN software required to install/run the suite is a build environment
-(i.e. C compiler, make etc.) for the C/XS modules. On some well known Linux package
-managers you can do:
+(i.e. C compiler, make etc.) for the C/XS modules and perl. On some well known Linux
+package managers you can do (as root or with sudo):
 
  # Debian/Ubuntu etc
- sudo apt install build-essential
+ apt-get update
+ apt-get install build-essential perl cpanminus
 
  # CentOS/Redhat
- sudo yum install gcc gcc-c++ kernel-devel make
+ yum update
+ yum install gcc make patch perl perl-App-cpanminus
 
-After that, you can use L<App::cpanminus> to install the benchmark suite:
+After that, you can use L<App::cpanminus> to install the benchmark suite (as
+root/sudo is the easiest, will install for all users):
 
  cpanm -n Benchmark::DKbench
 
@@ -159,18 +162,18 @@ C<dkbench --setup>) and use C<cpanm> to install any missing libraries.
 Using it with C<--force> will install the reference CPAN module versions, including
 BioPerl which is not a requirement for DKbench, but enables the BioPerl benchmarks.
 
-The reference CPAN versions are suggested if you want a fair comparison between
-systems and also for the benchmark Pass/Fail results to be reliable.
+The reference Perl and CPAN versions are suggested if you want a fair comparison
+between systems and also for the benchmark Pass/Fail results to be reliable.
 
 =head1 BENCHMARKS
 
-The suite consists of 19 benchmarks. With a successful installation of the DKbench
-package, 18 will run by default, although the C<BioPerl Monomers> requires BioPerl
+The suite consists of 21 benchmarks. With a successful installation of the DKbench
+package, 20 will run by default, although the C<BioPerl Monomers> requires BioPerl
 to be installed and Genbank data to be downloaded (C<dkbench --setup> can do the
-latter).
+latter), so you might start with 19 benchmarks running after a standard install.
 
-On MacOS only, the C<Time::Piece> benchmark will be skipped, unless you try a single
-thread run without MCE (C<--skip_mce>).
+On MacOS only, the C<Time::Piece> benchmark will be skipped, unless you use C<--no_mce>
+(making it single-thread only - see why below).
 
 =over 4
 
@@ -234,9 +237,8 @@ repeat was chosen to keep low memory (this is a pure Perl function no Math libra
 a utf8 string. Perl version can make a big difference, as Unicode behaviour has
 changed (old Perl versions are faster but less strict in general).
 
-=item * C<Text::Fuzzy> : The edit distance for strings of various lengths (up to 1000)
-are calculated using L<Text::Fuzzy> and L<Text::Levenshtein::Damerau::XS> (the latter
-is faster for Levenshtein-Damerau over long strings.
+=item * C<Text::Levenshtein> : The edit distance for strings of various lengths (up
+to 2500) are calculated using L<Text::Levenshtein::XS> and L<Text::Levenshtein::Damerau::XS>.
 
 =item * C<Time::Piece> : Creates and manipulates/converts Time::Piece objects. It
 is disabled by default on MacOS (unless C<--no_mce> is specified), as it runs
@@ -281,6 +283,18 @@ on the servers I was testing, to choose the optimal types for the company I was
 working for. The second version has expanded a bit over that and is friendlier to
 use.
 
+=head2 SCORES
+
+Some sample DKbench score results from various systems for comparison (all on
+reference setup with Perl 5.36.0):
+
+ CPU                                     Cores/HT   Single   Multi   Scalability
+ AMD Ryzen 5 PRO 4650U @ 2.1 (WSL)       6/12       906      4166    38.2% 
+ Apple M2 Pro @ 3.5 (MacOS)              12/12      1408     12338   73.1%
+ Ampere Altra @ 3.0 (Linux)              48/48      708      32718   97.7%
+ Intel Xeon Platinum 8481C @ 2.7 (Linux) 88/176     1000     86055   48.9%
+ AMD EPYC 7B13 @ 2.45 (Linux)            112/224    956      104536  49.3%
+
 =head1 AUTHOR
 
 Dimitrios Kechagias, C<< <dkechag at cpan.org> >>
@@ -307,36 +321,37 @@ the same terms as the Perl 5 programming language system itself.
 
 sub benchmark_list {
     return {               # idx : 0 = result, 1 = ref time, 2 = func, 3 = quick test, 4 = normal test, 5 = ver
-        'Astro'            => ['e71c7ae08f16fe26aea7cfdb72785873', 5.674, \&bench_astro, 20000, 80000],
-        'BioPerl Codons'   => ['97c443c099886ca60e99f7ab9df689b5', 8.752, \&bench_bioperl_codons, 3, 5, 1],
-        'BioPerl Monomers' => ['d29ed0a5c205c803c112be1338d1f060', 5.241, \&bench_bioperl_mono, 6, 20],
-        'Crypt::JWT'       => ['d41d8cd98f00b204e9800998ecf8427e', 6.451, \&bench_jwt, 250, 900],
-        'CSS::Inliner'     => ['82c1b6de9ca0500a48f8a8df0998df3c', 4.603, \&bench_css, 2, 5],
-        'DBI/SQL'          => ['2b8252daad9568a5b39038c696df4be3', 5.700, \&bench_dbi, 5000, 15000, 2.1],
-        'DateTime'         => ['b08d2eeb994083b7422f6c9d86fed2c6', 6.198, \&bench_datetime, 5000, 15000],
-        'Digest'           => ['4b69f6cf0f53cbf6c3444f2f767dd21d', 4.513, \&bench_digest, 50, 250],
-        'Encode'           => ['PASS 1025',                        5.725, \&bench_encode, 40, 120],
-        'HTML::FormatText' => ['8c2589f0a5276252805e11301fc2ab56', 4.756, \&bench_formattext, 4, 10],
-        'Imager'           => ['8829cb3703e884054eb025496f336c63', 6.792, \&bench_imager, 4, 16],
-        'JSON::XS'         => ['PASS',                             5.388, \&bench_json, 600, 2200],
-        'Math::DCT'        => ['766e3bfd7a2276f452bb3d1bd21939bc', 7.147, \&bench_dct, 25000, 100_000],
-        'Math::MatrixReal' => ['4606231b1309fb21ae1223fa0043fd76', 4.293, \&bench_matrixreal, 200, 650],
-        'Moose'            => ['d1cb92c513f6378506dfa11f694cffac', 4.968, \&bench_moose, 10_000, 30_000],
-        'Moose prove'      => ['PASS',                             7.974, \&bench_moose_prv, 0.5, 1],
-        'Primes'           => ['4266f70a7a9efb3484cf5d98eba32244', 3.680, \&bench_primes_m, 2, 5],
-        'Regex/Subst'      => ['30ce365b25f3d597578b3bdb14aa3f57', 4.652, \&bench_regex_asc, 8, 24],
-        'Regex/Subst utf8' => ['857eb4e63a4d174ca4a16fe678f7626f', 5.703, \&bench_regex_utf8, 3, 10],
-        'Text::Fuzzy'      => ['a71709068d1051ec5c2e05df82638dbe', 5.816, \&bench_textfuzzy, 12, 42, 2.1],
-        'Time::Piece'      => ['2d4b149fe7f873a27109fc376d69211b', 5.907, \&bench_timepiece, 75_000, 275_000],
+        'Astro'             => ['e71c7ae08f16fe26aea7cfdb72785873', 5.674, \&bench_astro, 20000, 80000],
+        'BioPerl Codons'    => ['97c443c099886ca60e99f7ab9df689b5', 8.752, \&bench_bioperl_codons, 3, 5, 1],
+        'BioPerl Monomers'  => ['d29ed0a5c205c803c112be1338d1f060', 5.241, \&bench_bioperl_mono, 6, 20],
+        'Crypt::JWT'        => ['d41d8cd98f00b204e9800998ecf8427e', 6.451, \&bench_jwt, 250, 900],
+        'CSS::Inliner'      => ['82c1b6de9ca0500a48f8a8df0998df3c', 4.603, \&bench_css, 2, 5],
+        'DBI/SQL'           => ['2b8252daad9568a5b39038c696df4be3', 5.700, \&bench_dbi, 5000, 15000, 2.1],
+        'DateTime'          => ['b08d2eeb994083b7422f6c9d86fed2c6', 6.198, \&bench_datetime, 5000, 15000],
+        'Digest'            => ['4b69f6cf0f53cbf6c3444f2f767dd21d', 4.513, \&bench_digest, 50, 250],
+        'Encode'            => ['PASS 1025',                        5.725, \&bench_encode, 40, 120],
+        'HTML::FormatText'  => ['8c2589f0a5276252805e11301fc2ab56', 4.756, \&bench_formattext, 4, 10],
+        'Imager'            => ['8829cb3703e884054eb025496f336c63', 6.792, \&bench_imager, 4, 16],
+        'JSON::XS'          => ['PASS',                             5.388, \&bench_json, 600, 2200],
+        'Math::DCT'         => ['766e3bfd7a2276f452bb3d1bd21939bc', 7.147, \&bench_dct, 25000, 100_000],
+        'Math::MatrixReal'  => ['4606231b1309fb21ae1223fa0043fd76', 4.293, \&bench_matrixreal, 200, 650],
+        'Moose'             => ['d1cb92c513f6378506dfa11f694cffac', 4.968, \&bench_moose, 10_000, 30_000],
+        'Moose prove'       => ['PASS',                             7.974, \&bench_moose_prv, 0.5, 1],
+        'Primes'            => ['4266f70a7a9efb3484cf5d98eba32244', 3.680, \&bench_primes_m, 2, 5],
+        'Regex/Subst'       => ['30ce365b25f3d597578b3bdb14aa3f57', 4.652, \&bench_regex_asc, 8, 24],
+        'Regex/Subst utf8'  => ['857eb4e63a4d174ca4a16fe678f7626f', 5.703, \&bench_regex_utf8, 3, 10],
+        'Text::Levenshtein' => ['2948a300ed9131fa0ce82bb5eabb8ded', 5.539, \&bench_textlevenshtein, 7, 25, 2.1],
+        'Time::Piece'       => ['2d4b149fe7f873a27109fc376d69211b', 5.907, \&bench_timepiece, 75_000, 275_000],
     };
 }
 
 sub system_identity {
+    local $^O = 'linux' if $^O =~ /android/;
     my $info  = System::Info->sysinfo_hash;
+    my $osn   = $info->{distro} || $info->{os} || $^O;
     my $model = $info->{cpu};
     my $cores = $info->{cpu_cores} || 1;
     my $arch  = $info->{cpu_type} || '';
-    my $osn   = $info->{distro} || $info->{os} || $^O;
     $arch = " ($arch)" if $arch;
     if ($^O =~ /darwin/ && $model =~ /^Mac|nknown/) {
         my $brand = `sysctl -a |grep brand`;
@@ -344,11 +359,11 @@ sub system_identity {
             $model = $1;
         }
     }
-    print "------------ Software ------------\nDKbench v$VERSION\n";
+    print "--------------- Software ---------------\nDKbench v$VERSION\n";
     print "Perl $^V\n";
-    print "OS: $osn\n------------ Hardware ------------\n";
+    print "OS: $osn\n--------------- Hardware ---------------\n";
     print "CPU type: $model$arch\n";
-    print "Cores: $cores\n".("-"x34)."\n";
+    print "CPUs: $cores\n".("-"x40)."\n";
 
     return $cores;
 };
@@ -385,18 +400,20 @@ sub calc_scalability {
     my (@perf, @scal);
     print "Multi thread Scalability:\n".pad_to("Benchmark",24).pad_to("Multi perf xSingle",24).pad_to("Multi scalability %",24);
     print "\n";
+    my $cnt;
     foreach my $bench (sort keys %$benchmarks) {
         next unless $stats1->{$bench}->{times} && $stats2->{$bench}->{times};
+        $cnt++;
         my @res1 = min_max_avg($stats1->{$bench}->{times});
         my @res2 = min_max_avg($stats2->{$bench}->{times});
         push @perf, $res1[2]/$res2[2]*$threads if $res2[2];
         push @scal, $res1[2]/$res2[2]*100 if $res2[2];
         print pad_to("$bench:",24).pad_to(sprintf("%.2f",$perf[-1]),24).pad_to(sprintf("%2.0f",$scal[-1]),24)."\n";
     }
-    print (("-"x34)."\n");
-    my ($avg1) = min_max_avg($stats1->{total}->{$display});
-    my ($avg2) = min_max_avg($stats2->{total}->{$display});
-    print "DKbench summary:\n";
+    print (("-"x40)."\n");
+    my $avg1 = min_max_avg($stats1->{total}->{$display});
+    my $avg2 = min_max_avg($stats2->{total}->{$display});
+    print "DKbench summary ($cnt benchmarks, $stats2->{threads} threads):\n";
     print pad_to("Single:").sprintf($opt->{f}, $avg1)."\n";
     print pad_to("Multi:").sprintf($opt->{f}, $avg2)."\n";
     my @newperf = Benchmark::DKbench::drop_outliers(\@perf, -1);
@@ -918,23 +935,23 @@ sub bench_subst {
     return "$count Replaced";
 }
 
-sub bench_textfuzzy {
+sub bench_textlevenshtein {
     my $iter = shift;
     my $d    = Digest->new("MD5");
     my $data = _fuzzy_data();
     my $diff;
     foreach (1..$iter) {
-        foreach my $sz (qw/10 100 1000/) {
-            my $i = int(rand(10));
-            my $tf = Text::Fuzzy->new($data->{$sz}->[$i]);
-            $diff = $tf->distance($data->{$sz}->[$_]) for 0..9;
-            $d->add($diff);
-            $tf = Text::Fuzzy->new($data->{$sz}->[$i], trans => 1, max => 100);
-            $diff = $tf->distance($data->{$sz}->[$_]) for 0..9;
-            $d->add($diff);
+        foreach my $sz (qw/10 100 1000 2500/) {
+            my $n = scalar @{$data->{$sz}};
+            my $i = int(rand($n));
+            $diff = Text::Levenshtein::XS::distance(
+                $data->{$sz}->[$i], $data->{$sz}->[$_]
+            ) for 0..$n-1;
+            $d->add($diff || -1);
+            next if $sz > 1000;
             $diff = Text::Levenshtein::Damerau::XS::xs_edistance(
                 $data->{$sz}->[$i], $data->{$sz}->[$_]
-            ) for 1..9;
+            ) for 0..$n-1;
             $d->add($diff);
         }
     }
@@ -1055,9 +1072,10 @@ sub _random_uchar {
 sub _fuzzy_data {
     my %data;
     push @{$data{10}}, join('', map {_random_uchar()} 1..(8+int(rand(5))))
-        for 0..9;
-    push @{$data{100}}, $data{10}->[$_]x10 for 0..9;
-    push @{$data{1000}}, _random_str(50,1)x20 for 0..9;
+        for 0..99;
+    push @{$data{100}}, $data{10}->[$_]x10 for 0..49;
+    push @{$data{1000}}, _random_str(50,1)x20 for 0..7;
+    push @{$data{2500}}, _random_str(50,1)x50 for 0..3;
     return \%data;
 }
 
